==> igniteui-react-inputs-18.6.1.tgz: package/esm2015/lib/CalendarVisualModelExport.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { StringBuilder } from "igniteui-react-core";
import { stringIsNullOrEmpty } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let CalendarVisualModelExport = /*@__PURE__*/ (() => {
    class CalendarVisualModelExport extends Base {
        constructor() {
            super(...arguments);
            this.i = 0;
            this.h = 0;
            this.e = null;
            this.g = null;
            this.c = null;
            this.f = null;
            this.d = null;
            this.b = null;
            this.a = null;
            this.r = null;
            this.s = null;
            this.t = null;
            this.m = 0;
            this.p = null;
            this.q = null;
            this.n = null;
            this.j = null;
            this.k = null;
            this.l = null;
        }
        o() {
            let a = new StringBuilder(0);
            a.l("{");
            a.l("Density : " + this.i + ", ");
            a.l("BaseTheme : " + this.h + ", ");
            a.l("SelectedDateBackgroundColor : " + this.e.serialize() + ", ");
            a.l("SelectedFocusDateBackgroundColor : " + this.g.serialize() + ", ");
            a.l("FocusDateBackgroundColor : " + this.c.serialize() + ", ");
            a.l("SelectedDateTextColor : " + this.f.serialize() + ", ");
            a.l("FocusDateTextColor : " + this.d.serialize() + ", ");
            a.l("CurrentDateTextColor : " + this.b.serialize() + ", ");
            a.l("CurrentDateBorderColor : " + this.a.serialize() + ", ");
            if (!stringIsNullOrEmpty(this.r)) {
                a.l("textStyleFontStyle : \"" + this.r + "\", ");
            }
            if (!stringIsNullOrEmpty(this.s)) {
                a.l("textStyleFontVariant : \"" + this.s + "\", ");
            }
            if (!stringIsNullOrEmpty(this.t)) {
                a.l("textStyleFontWeight : \"" + this.t + "\", ");
            }
            if (!stringIsNullOrEmpty(this.p)) {
                a.l("textStyleFontFamily : \"" + this.p + "\", ");
            }
            if (!stringIsNullOrEmpty(this.q)) {
                a.l("textStyleFontStretch : \"" + this.q + "\", ");
            }
            if (!isNaN_(this.m)) {
                a.l("textStyleFontSize : " + this.m + ", ");
            }
            a.l("activePicker : \"" + this.n + "\", ");
            a.l("buttonsModels: [");
            for (let b = 0; b < this.j.count; b++) {
                if (b != 0) {
                    a.l(",");
                }
                let c = this.j._inner[b].aa.charAt(0).toString().toLowerCase() + this.j._inner[b].aa.substr(1);
                a.l(this.j._inner[b].ab());
            }
            a.l("],");
            a.l("dayNamesModels: [");
            for (let d = 0; d < this.k.count; d++) {
                if (d != 0) {
                    a.l(",");
                }
                a.l(this.k._inner[d].h());
            }
            a.l("],");
            a.l("weekNumbersModels: [");
            for (let e = 0; e < this.l.count; e++) {
                if (e != 0) {
                    a.l(",");
                }
                a.l(this.l._inner[e].h());
            }
            a.l("]");
            a.l("}");
            return a.toString();
        }
    }
    CalendarVisualModelExport.$t = /*@__PURE__*/ markType(CalendarVisualModelExport, 'CalendarVisualModelExport');
    return CalendarVisualModelExport;
})();

==> igniteui-react-inputs-18.7.3.tgz: package/esm2015/lib/CalendarVisualModelExport.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { StringBuilder } from "igniteui-react-core";
import { stringIsNullOrEmpty } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let CalendarVisualModelExport = /*@__PURE__*/ (() => {
    class CalendarVisualModelExport extends Base {
        constructor() {
            super(...arguments);
            this.i = 0;
            this.h = 0;
            this.e = null;
            this.g = null;
            this.c = null;
            this.f = null;
            this.d = null;
            this.b = null;
            this.a = null;
            this.r = null;
            this.s = null;
            this.t = null;
            this.m = 0;
            this.p = null;
            this.q = null;
            this.n = null;
            this.j = null;
            this.k = null;
            this.l = null;
        }
        o() {
            let a = new StringBuilder(0);
            a.l("{");
            a.l("Density : " + this.i + ", ");
            a.l("BaseTheme : " + this.h + ", ");
            a.l("SelectedDateBackgroundColor : " + this.e.serialize() + ", ");
            a.l("SelectedFocusDateBackgroundColor : " + this.g.serialize() + ", ");
            a.l("FocusDateBackgroundColor : " + this.c.serialize() + ", ");
            a.l("SelectedDateTextColor : " + this.f.serialize() + ", ");
            a.l("FocusDateTextColor : " + this.d.serialize() + ", ");
            a.l("CurrentDateTextColor : " + this.b.serialize() + ", ");
            a.l("CurrentDateBorderColor : " + this.a.serialize() + ", ");
            if (!stringIsNullOrEmpty(this.r)) {
                a.l("textStyleFontStyle : \"" + this.r + "\", ");
            }
            if (!stringIsNullOrEmpty(this.s)) {
                a.l("textStyleFontVariant : \"" + this.s + "\", ");
            }
            if (!stringIsNullOrEmpty(this.t)) {
                a.l("textStyleFontWeight : \"" + this.t + "\", ");
            }
            if (!stringIsNullOrEmpty(this.p)) {
                a.l("textStyleFontFamily : \"" + this.p + "\", ");
            }
            if (!stringIsNullOrEmpty(this.q)) {
                a.l("textStyleFontStretch : \"" + this.q + "\", ");
            }
            if (!isNaN_(this.m)) {
                a.l("textStyleFontSize : " + this.m + ", ");
            }
            a.l("activePicker : \"" + this.n + "\", ");
            a.l("buttonsModels: [");
            for (let b = 0; b < this.j.count; b++) {
                if (b != 0) {
                    a.l(",");
                }
                let c = this.j._inner[b].aa.charAt(0).toString().toLowerCase() + this.j._inner[b].aa.substr(1);
                a.l(this.j._inner[b].serialize());
            }
            a.l("],");
            a.l("dayNamesModels: [");
            for (let d = 0; d < this.k.count; d++) {
                if (d != 0) {
                    a.l(",");
                }
                a.l(this.k._inner[d].h());
            }
            a.l("],");
            a.l("weekNumbersModels: [");
            for (let e = 0; e < this.l.count; e++) {
                if (e != 0) {
                    a.l(",");
                }
                a.l(this.l._inner[e].h());
            }
            a.l("]");
            a.l("}");
            return a.toString();
        }
    }
    CalendarVisualModelExport.$t = /*@__PURE__*/ markType(CalendarVisualModelExport, 'CalendarVisualModelExport');
    return CalendarVisualModelExport;
})();
